// $Id: serverlog.cpp,v 1.18 2011/11/22 13:07:44 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.	See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA	02111-1307 USA
*
*
*******************************************************************************/

#include <signal.h>

#include <unistd.h>

#include "Application.h"
#include "Debug.h"
#include "DefaultOptions.h"
#include "ErrorHandler.h"
#include "Singleton.h"
#include "XmlOptions.h"



//_______________________________
//! to handle keyboard interuptions
void interupt( int sig );

//__________________________________________
int main (int argc, char *argv[])
{
    // Ensure proper cleaning at exit
    signal(SIGINT,	interupt);
    signal(SIGTERM, interupt);

    // install error handler
    qInstallMsgHandler( ErrorHandler::Throw );
    CommandLineArguments arguments( argc, argv );
    CommandLineParser parser( SERVER::ApplicationManager::commandLineParser( arguments, false ) );
    if( parser.hasFlag( "--no-server" ) )
    {
        Debug::Throw(0) << "serverlog - by definition the application cannot work in 'no-server' mode." << endl;
        Debug::Throw(0) << "aborting." << endl;
        return 0;
    }

    // dump help
    if( parser.hasFlag( "--help" ) )
    {
        Application::usage();
        return 0;
    }

    // install additional options
    installDefaultOptions();
    XmlOptions::read( XmlOptions::get().raw( "RC_FILE" ) );
    Debug::setLevel( XmlOptions::get().get<int>( "DEBUG_LEVEL" ) );

    Q_INIT_RESOURCE( basePixmaps );
    Q_INIT_RESOURCE( pixmaps );
    QApplication application( argc, argv );
    application.setApplicationName( "serverlog" );
    Application singleton( CommandLineArguments( argc, argv ) );
    Singleton::get().setApplication( &singleton );
    singleton.initApplicationManager();

    application.exec();

    return 0;

}

//_____________________________________________
void interupt( int sig )
{
    Debug::Throw() << "interupt - Recieved signal " << sig << endl;
    qApp->quit();
}
